## Typing stubs for regex

This is a [type stub package](https://typing.python.org/en/latest/tutorials/external_libraries.html)
for the [`regex`](https://github.com/mrabarnett/mrab-regex) package. It can be used by type checkers
to check code that uses `regex`. This version of
`types-regex` aims to provide accurate annotations for
`regex==2025.11.3`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/regex`](https://github.com/python/typeshed/tree/main/stubs/regex)
directory.

This package was tested with the following type checkers:
* [mypy](https://github.com/python/mypy/) 1.18.2
* [pyright](https://github.com/microsoft/pyright) 1.1.407

It was generated from typeshed commit
[`65b8a85e4b775d5465e7fdb7382c181fb7efa958`](https://github.com/python/typeshed/commit/65b8a85e4b775d5465e7fdb7382c181fb7efa958).